# If we should verify tarball signature with GPGv2.
%global verify_tarball_signature 1

# If there are patches which touch autotools files, set this to 1.
%global patches_touch_autotools %{nil}

# The source directory.
%global source_directory 2.1-development

Name:          virt-v2v
Epoch:         1
Version:       2.1.10
Release:       %mkrel 2
Summary:       Convert a virtual machine to run on KVM
Group:         System/Kernel and hardware

License:       GPLv2+
URL:           https://github.com/libguestfs/virt-v2v

Source0:       https://download.libguestfs.org/virt-v2v/%{source_directory}/%{name}-%{version}.tar.gz
%if 0%{verify_tarball_signature}
Source1:       https://download.libguestfs.org/virt-v2v/%{source_directory}/%{name}-%{version}.tar.gz.sig
# Keyring used to verify tarball signature.
Source2:       libguestfs.keyring
%endif

# Maintainer script which helps with handling patches.
Source3:       copy-patches.sh

%if 0%{patches_touch_autotools}
BuildRequires: autoconf, automake, libtool
%endif

BuildRequires: make
# (tv) for /usr/bin/pod2man:
BuildRequires: perl
BuildRequires: gcc
BuildRequires: ocaml >= 4.04

BuildRequires: libguestfs-devel >= 1:1.44
BuildRequires: augeas-devel
BuildRequires: bash-completion
BuildRequires: file-devel
BuildRequires: gettext-devel
BuildRequires: jansson-devel
BuildRequires: pkgconfig(libnbd)
BuildRequires: libosinfo-devel
BuildRequires: libvirt-devel
BuildRequires: libvirt-utils
BuildRequires: libxml2-devel
BuildRequires: pcre2-devel
BuildRequires: perl(Sys::Guestfs)
BuildRequires: po4a
# (tv) for /usr/bin/virsh:
BuildRequires: libvirt-utils
BuildRequires: xorriso

BuildRequires: ocaml-findlib-devel
BuildRequires: ocaml-libguestfs-devel
BuildRequires: ocaml-libvirt-devel
BuildRequires: ocaml-libnbd-devel
BuildRequires: ocaml-fileutils-devel
BuildRequires: ocaml-gettext-devel
BuildRequires: ocaml-ounit-devel

#BuildRequires: nbdkit-python-plugin
%ifarch x86_64
BuildRequires: glibc-static-devel
%endif

%if 0%{verify_tarball_signature}
BuildRequires: gnupg2
%endif

Requires:      libguestfs%{?_isa} >= 1:1.42
Requires:      guestfs-tools >= 1.42

# For Windows conversions on RHEL.
#Requires:      libguestfs-winsupport >= 7.2

Requires:      gawk
Requires:      gzip
Requires:      unzip
Requires:      curl
Requires:      openssh-clients >= 8.8p1
# (tv) for /usr/bin/virsh:
Requires:	libvirt-utils

# Ensure the UEFI firmware is available, to properly convert
# EFI guests (RHBZ#1429643).
%ifarch x86_64
Requires:      edk2-ovmf
%endif
%ifarch aarch64
Requires:      edk2-aarch64
%endif

Requires:      python3
# Needed for -it vddk, and -o rhv-upload.
Recommends:      nbdkit
Requires:        qemu-img
Recommends:      nbdkit-curl-plugin
Recommends:      nbdkit-python-plugin
Recommends:      nbdkit-ssh-plugin
%ifarch x86_64
Recommends:      nbdkit-vddk-plugin
%endif
Recommends:      nbdkit-cacheextents-filter
Recommends:      nbdkit-cow-filter >= 1.26.5-1.el9
Recommends:      nbdkit-rate-filter
Recommends:      nbdkit-retry-filter

# For rhsrvany.exe, used to install firstboot scripts in Windows guests.
Requires:      mingw32-srvany >= 1.0-13

%description
Virt-v2v converts a single guest from a foreign hypervisor to run on
KVM.  It can read Linux and Windows guests running on VMware, Xen,
Hyper-V and some other hypervisors, and convert them to KVM managed by
libvirt, OpenStack, oVirt, Red Hat Virtualisation (RHV) or several
other targets.  It can modify the guest to make it bootable on KVM and
install virtio drivers so it will run quickly.


%package bash-completion
Summary:       Bash tab-completion for %{name}
BuildArch:     noarch
Requires:      bash-completion >= 2.0
Requires:      %{name} >= %{epoch}:%{version}-%{release}


%description bash-completion
Install this package if you want intelligent bash tab-completion
for %{name}.


%package man-pages-ja
Summary:       Japanese (ja) man pages for %{name}
Group:         Documentation
BuildArch:     noarch
Requires:      %{name} >= %{epoch}:%{version}-%{release}

%description man-pages-ja
%{name}-man-pages-ja contains Japanese (ja) man pages
for %{name}.


%package man-pages-uk
Summary:       Ukrainian (uk) man pages for %{name}
Group:         Documentation
BuildArch:     noarch
Requires:      %{name} >= %{epoch}:%{version}-%{release}

%description man-pages-uk
%{name}-man-pages-uk contains Ukrainian (uk) man pages
for %{name}.


%prep
%if 0%{verify_tarball_signature}
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%endif
%autosetup -p1

%if 0%{patches_touch_autotools}
autoreconf -i
%endif


%build
%configure \
  --with-extra="mageia=%{mageia},release=%{release}" \

%make_build


%install
%make_install

# Delete libtool crap.
find $RPM_BUILD_ROOT -name '*.la' -delete

# Virt-tools data directory.  This contains symlinks to rhsrvany.exe
# and pnp_wait.exe which are satisfied by the dependency on
# mingw32-srvany.
mkdir -p $RPM_BUILD_ROOT%{_datadir}/virt-tools
pushd $RPM_BUILD_ROOT%{_datadir}/virt-tools
ln -sf ../../i686-w64-mingw32/sys-root/mingw/bin/rhsrvany.exe
ln -sf ../../i686-w64-mingw32/sys-root/mingw/bin/pnp_wait.exe
popd

# Find locale files.
%find_lang %{name}


%check
# All tests fail at the moment because of bugs in libvirt blockdev.
# # Tests fail on both armv7 and ppc64le in Fedora 31 because the kernel
# # cannot boot on qemu.
# %ifnarch %{arm} ppc64le

# # On x86_64 this single test fails with: "virt-v2v: warning: the
# # target hypervisor does not support a x86_64 KVM guest".  Missing
# # BuildRequires?
# %ifarch x86_64
# truncate -s 0 tests/test-v2v-o-libvirt.sh
# %endif

# # This test fails in mock.
# truncate -s 0 tests/test-v2v-oa-option.sh

# # Make sure we can see the debug messages (RHBZ#1230160).
# export LIBGUESTFS_DEBUG=1
# export LIBGUESTFS_TRACE=1

# %make_build check || {
#     cat tests/test-suite.log
#     exit 1
#   }

# %endif


%files -f %{name}.lang
%license COPYING
%doc README
%{_bindir}/virt-v2v
%{_bindir}/virt-v2v-in-place
%{_bindir}/virt-v2v-inspector
%{_mandir}/man1/virt-v2v.1*
%{_mandir}/man1/virt-v2v-hacking.1*
%{_mandir}/man1/virt-v2v-input-vmware.1*
%{_mandir}/man1/virt-v2v-input-xen.1*
%{_mandir}/man1/virt-v2v-in-place.1*
%{_mandir}/man1/virt-v2v-inspector.1*
%{_mandir}/man1/virt-v2v-output-local.1*
%{_mandir}/man1/virt-v2v-output-openstack.1*
%{_mandir}/man1/virt-v2v-output-rhv.1*
%{_mandir}/man1/virt-v2v-release-notes-1.42.1*
%{_mandir}/man1/virt-v2v-release-notes-2.0.1*
%{_mandir}/man1/virt-v2v-support.1*
%{_datadir}/virt-tools


%files bash-completion
%license COPYING
%{_datadir}/bash-completion/completions/virt-v2v


%files man-pages-ja
%license COPYING
%lang(ja) %{_mandir}/ja/man1/*.1*


%files man-pages-uk
%license COPYING
%lang(uk) %{_mandir}/uk/man1/*.1*




%changelog
* Wed May 10 2023 neoclust <neoclust> 1:2.1.10-2.mga9
+ Revision: 1956475
- As we build libguests on i586 on mageia, we can build this one too

* Sat Dec 03 2022 tv <tv> 1:2.1.10-1.mga9
+ Revision: 1915961
- New upstream development version 2.1.10
- New tool: virt-v2v-inspector

* Tue Nov 08 2022 tv <tv> 1:2.1.9-1.mga9
+ Revision: 1904702
- New upstream development version 2.1.9
- New upstream development version 2.1.7

* Wed Jun 29 2022 tv <tv> 1:2.1.6-1.mga9
+ Revision: 1866671
- New upstream development version 2.1.6

* Fri Jun 24 2022 papoteur <papoteur> 1:2.1.2-2.mga9
+ Revision: 1865710
- Mass Rebuild for dependencies

* Thu Apr 28 2022 tv <tv> 1:2.1.2-1.mga9
+ Revision: 1854890
- New upstream development version 2.1.2

* Wed Apr 13 2022 tv <tv> 1:2.1.1-1.mga9
+ Revision: 1849282
- New upstream development version 2.1.1

* Wed Apr 06 2022 tv <tv> 1:2.0.2-1.mga9
+ Revision: 1846224
- New upstream stable branch version 2.0.2

* Wed Mar 23 2022 tv <tv> 1:2.0.1-1.mga9
+ Revision: 1822767
- New upstream stable branch version 2.0.1
- Fixes security issue when running virt-v2v as root (RHBZ#2066773).

* Wed Mar 16 2022 tv <tv> 1:2.0.0-1.mga9
+ Revision: 1794752
- New upstream stable branch version 2.0.0
- Don't use absolute symlinks.

* Sun Mar 13 2022 tv <tv> 1:1.45.99-1.mga9
+ Revision: 1790760
- New upstream development version 1.45.99 (preview of 2.0)
- Add symlink to pnp_wait.exe from the virt tools directory (rhbz#1788823)

* Wed Feb 16 2022 tv <tv> 1:1.45.98-1.mga9
+ Revision: 1778269
- New upstream development version 1.45.99 (preview of 2.0)

* Mon Feb 14 2022 tmb <tmb> 1:1.45.97-2.mga9
+ Revision: 1774872
- rebuild for python 3.10
+ tv <tv>
- New upstream development version 1.45.97 (preview of 2.0)

* Fri Jan 07 2022 tv <tv> 1:1.45.96-1.mga9
+ Revision: 1767243
- New upstream development version 1.45.96 (preview of 2.0)

* Wed Dec 22 2021 tv <tv> 1:1.45.95-1.mga9
+ Revision: 1763282
- New upstream development version 1.45.95 (preview of 2.0)

* Mon Dec 13 2021 tv <tv> 1:1.45.94-1.mga9
+ Revision: 1761927
- New upstream development version 1.45.94 (preview of 2.0)

* Sat Dec 04 2021 tv <tv> 1:1.45.93-1.mga9
+ Revision: 1760702
- New upstream development version 1.45.93 (preview of 2.0)

* Wed Nov 24 2021 tv <tv> 1:1.45.91-1.mga9
+ Revision: 1759030
- New upstream development version 1.45.91 (preview of 2.0)

* Sat Oct 16 2021 tv <tv> 1:1.45.90-2.mga9
+ Revision: 1751770
- New upstream development version 1.45.90 (preview of 2.0)

* Tue Jul 06 2021 tv <tv> 1:1.45.2-1.mga9
+ Revision: 1734933
- New upstream development version 1.45.2.
- New upstream development version 1.45.1.

* Thu May 06 2021 tv <tv> 1:1.44.0-1.mga9
+ Revision: 1721664
- New upstream stable branch version 1.44.0.

* Wed Apr 14 2021 tv <tv> 1:1.43.5-1.mga9
+ Revision: 1715739
- New upstream version 1.43.5

* Fri Apr 02 2021 tv <tv> 1:1.43.4-4.mga9
+ Revision: 1712556
- Change libguestfs-tools-c -> guestfs-tools.
- Switch to xorriso
- No filedeps (even if it worked)

* Thu Apr 01 2021 tv <tv> 1:1.43.4-3.mga9
+ Revision: 1712460
- Rebuild on armv7 with now successfuly built libguestfs

* Tue Mar 30 2021 tv <tv> 1:1.43.4-2.mga9
+ Revision: 1711880
- Requires libguestfs-tools now

* Mon Mar 22 2021 tv <tv> 1:1.43.4-1.mga9
+ Revision: 1707949
- 1.43.4

* Thu Jan 07 2021 luigiwalser <luigiwalser> 1:1.43.2-4.mga8
+ Revision: 1669637
- use ExclusiveArch instead of ExcludeArch, as latter does not work for noarch
+ tv <tv>
- Drop obsolete virt-v2v-copy-to-local tool

* Fri Dec 04 2020 tv <tv> 1:1.43.2-2.mga8
+ Revision: 1652509
- Add Mageia branding
- requires edk2 firmware
- bump needed versions

* Tue Dec 01 2020 tv <tv> 1:1.43.2-1.mga8
+ Revision: 1651318
- 1.43.2

* Sun Sep 20 2020 tv <tv> 1:1.43.1-1.mga8
+ Revision: 1628903
- switch to devel branch (thus fixing build)
- rebuild for perl-5.32

* Wed May 06 2020 tv <tv> 1:1.42.0-3.mga8
+ Revision: 1581072
- Re-add Epoch in requires

* Thu Apr 16 2020 tv <tv> 1:1.42.0-2.mga8
+ Revision: 1567866
- 1.42.0

* Wed Mar 11 2020 tv <tv> 1:1.41.8-2.mga8
+ Revision: 1555605
- set epoch for upgrade
- imported package virt-v2v


* Wed Mar 11 2020 Thierry Vignaud <tv@mageia.org> 1.41.8-1.mga8
- import from FC as it was split from libguestfs
